@@ -20,14 +20,18 @@
 
 """General implementation of walking commits and their contents."""
 
-
 import collections
 import heapq
 from itertools import chain
-from typing import Deque, List, Optional, Set, Tuple
+from typing import Deque, Dict, List, Optional, Set, Tuple
 
-from .diff_tree import (RENAME_CHANGE_TYPES, RenameDetector, tree_changes,
-                        tree_changes_for_merge)
+from .diff_tree import (
+    RENAME_CHANGE_TYPES,
+    RenameDetector,
+    TreeChange,
+    tree_changes,
+    tree_changes_for_merge,
+)
 from .errors import MissingCommitError
 from .objects import Commit, ObjectID, Tag
 
@@ -43,11 +47,11 @@ _MAX_EXTRA_COMMITS = 5
 class WalkEntry:
     """Object encapsulating a single result from a walk."""
 
-    def __init__(self, walker, commit):
+    def __init__(self, walker, commit) -> None:
         self.commit = commit
         self._store = walker.store
         self._get_parents = walker.get_parents
-        self._changes = {}
+        self._changes: Dict[str, List[TreeChange]] = {}
         self._rename_detector = walker.rename_detector
 
     def changes(self, path_prefix=None):
@@ -111,17 +115,14 @@ class WalkEntry:
             self._changes[path_prefix] = cached
         return self._changes[path_prefix]
 
-    def __repr__(self):
-        return "<WalkEntry commit={}, changes={!r}>".format(
-            self.commit.id,
-            self.changes(),
-        )
+    def __repr__(self) -> str:
+        return f"<WalkEntry commit={self.commit.id}, changes={self.changes()!r}>"
 
 
 class _CommitTimeQueue:
     """Priority queue of WalkEntry objects by commit time."""
 
-    def __init__(self, walker: "Walker"):
+    def __init__(self, walker: "Walker") -> None:
         self._walker = walker
         self._store = walker.store
         self._get_parents = walker.get_parents
@@ -234,7 +235,7 @@ class Walker:
         store,
         include: List[bytes],
         exclude: Optional[List[bytes]] = None,
-        order: str = 'date',
+        order: str = "date",
         reverse: bool = False,
         max_entries: Optional[int] = None,
         paths: Optional[List[bytes]] = None,
@@ -244,7 +245,7 @@ class Walker:
         until: Optional[int] = None,
         get_parents=lambda commit: commit.parents,
         queue_cls=_CommitTimeQueue,
-    ):
+    ) -> None:
         """Constructor.
 
         Args:
